@@ -4,12 +4,19 @@ import logging
 import traceback
 version = "latest"
 
+from pkg_resources import Requirement, resource_filename
+
 #READ config
 SAGA_BLISS=False
 try:
     import ConfigParser
     _CONFIG_FILE="bigjob.conf"
-    _conf_file = os.path.dirname(os.path.abspath( __file__ )) + "/../" + _CONFIG_FILE
+    _conf_file = resource_filename(Requirement.parse("BigJob"), _CONFIG_FILE)
+    
+    if _conf_file == None or _conf_file=="":
+        _conf_file = os.path.dirname(os.path.abspath( __file__ )) + "/../" + _CONFIG_FILE
+    
+    
     _config = ConfigParser.ConfigParser()
     _config.read(_conf_file)
     default_dict = _config.defaults()
